@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -459,6 +459,18 @@ da_cat_get(guint32 key)
 }
 
 
+gchar *da_cat_get_name(Category *item)
+{
+gchar *name = NULL;
+
+	if(item != NULL)
+	{
+		name = item->key == 0 ? _("(no category)") : item->fullname;
+	}
+	return name;
+}
+
+
 void da_cat_consistency(Category *item)
 {
 gboolean isIncome;
@@ -533,24 +545,22 @@ da_cat_debug_list(void)
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
+
 guint32 category_report_id(guint32 key, gboolean subcat)
 {
-Category *catentry = da_cat_get(key);
 guint32 retval = 0;
 
-	if(catentry)
+	if(subcat == FALSE)
 	{
-		if(subcat == FALSE)
-		{
+	Category *catentry = da_cat_get(key);
+		if(catentry)
 			retval = (catentry->flags & GF_SUB) ? catentry->parent : catentry->key;
-		}
-		else
-		{
-			retval = catentry->key;
-		}
-		DB( g_print("- cat '%s' reportid = %d\n", catentry->name, retval) );
 	}
-	
+	else
+	{
+		retval = key;
+	}
+	//DB( g_print("- cat '%s' reportid = %d\n", catentry->name, retval) );
 	return retval;
 }
 
@@ -957,10 +967,7 @@ const gchar *encoding;
 							fullcatname = g_strdup_printf("%s:%s", lastcatname, str_array[2]);
 						}
 
-						DB( g_print(" + fullcatname %s\n", fullcatname) );
-
 						item = da_cat_append_ifnew_by_fullname(fullcatname);
-
 						DB( g_print(" + item %p\n", item) );
 
 						if( item != NULL)
@@ -975,14 +982,10 @@ const gchar *encoding;
 						g_strfreev (str_array);
 					}
 				}
-
 			}
 			g_free(tmpstr);
-
 		}
 		g_io_channel_unref (io);
-
-
 	}
 
 	g_free(lastcatname);
@@ -1054,6 +1057,13 @@ category_type_get(Category *item)
 }
 
 
+gchar
+category_get_type_char(Category *item)
+{
+	return (item->flags & GF_INCOME) ? '+' : '-';
+}
+
+
 static gint 
 category_change_type_eval(Category *item, gboolean isIncome)
 {
