@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -61,6 +61,7 @@ gboolean da_cat_append(Category *cat);
 Category *da_cat_append_ifnew_by_fullname(gchar *rawfullname);
 
 Category *da_cat_get(guint32 key);
+gchar *da_cat_get_name(Category *item);
 Category *da_cat_get_by_fullname(gchar *rawfullname);
 
 void da_cat_consistency(Category *item);
@@ -77,6 +78,7 @@ gboolean category_rename(Category *item, const gchar *newname);
 
 gchar *category_find_preset(gchar **lang);
 gint category_type_get(Category *item);
+gchar category_get_type_char(Category *item);
 gint category_change_type(Category *item, gboolean isIncome);
 
 gboolean category_load_csv(gchar *filename, gchar **error);
