@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -83,6 +83,29 @@ static GPtrArray *da_split_new_full(guint size)
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
+static gint da_splits_compare_func(gpointer a, gpointer b)
+{
+Split *sa = *(Split **)a;
+Split *sb = *(Split **)b;	
+
+	DB( g_print(" sort %d %s - %d %s\n", sa->pos, sa->memo, sb->pos, sb->memo) );
+
+	return sa->pos - sb->pos;
+}
+
+void da_splits_sort(GPtrArray *splits)
+{
+	DB( g_print("da_splits_sort\n") );
+
+	if(splits == NULL)
+	{
+		//g_warning("NULL splits");
+		return;
+	}
+
+	g_ptr_array_sort(splits, (GCompareFunc) da_splits_compare_func);
+}
+
 
 guint da_splits_length(GPtrArray *splits)
 {
