@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -186,8 +186,6 @@ guint32 max_key = 0;
 }
 
 
-
-
 /**
  * da_tag_get_by_name:
  *
@@ -256,12 +254,27 @@ guint count;
 }
 
 
+static gboolean
+tags_key_exists(guint32 *tags, guint32 key)
+{
+guint count = 0;
+	while(*tags != 0 && count < 32)
+	{
+		if( *tags == key )
+			return TRUE;
+		tags++;
+		count++;
+	}
+	return FALSE;
+}
+
 
 guint32 *
 tags_parse(const gchar *tagstring)
 {
 gchar **str_array;
 guint32 *tags = NULL;
+guint32 *ptags;
 guint count, i;
 Tag *tag;
 
@@ -271,11 +284,18 @@ Tag *tag;
 	{
 		str_array = g_strsplit (tagstring, " ", 0);
 		count = g_strv_length( str_array );
+		DB( g_print("- %d tags '%s'\n", count, tagstring) );
 		if( count > 0 )
 		{
 			tags = g_new0(guint32, count + 1);
+			ptags = tags;
 			for(i=0;i<count;i++)
 			{
+				//5.2.3 fixed empty tag
+				if( strlen(str_array[i]) == 0 )
+					continue;
+
+				DB( g_print("- %d search '%s'\n", i, str_array[i]) );
 				tag = da_tag_get_by_name(str_array[i]);
 				if(tag == NULL)
 				{
@@ -285,9 +305,13 @@ Tag *tag;
 					da_tag_append(newtag);
 					tag = da_tag_get_by_name(str_array[i]);
 				}
-				tags[i] = tag->key;
+				DB( g_print("- array add %d '%s'\n", tag->key, tag->name) );
+
+				//5.3 fixed duplicate tag in same tags
+				if( tags_key_exists(tags, tag->key) == FALSE )
+					*ptags++ = tag->key;
 			}
-			tags[i] = 0;
+			*ptags = 0;
 		}
 
 		g_strfreev (str_array);
@@ -301,7 +325,7 @@ gchar *
 tags_tostring(guint32 *tags)
 {
 guint count, i;
-gchar **str_array;
+gchar **str_array, **tptr;
 gchar *tagstring;
 Tag *tag;
 
@@ -314,16 +338,17 @@ Tag *tag;
 	{
 		count = tags_count(tags);
 		str_array = g_new0(gchar*, count+1);
+		tptr = str_array;
 		for(i=0;i<count;i++)
 		{
 			tag = da_tag_get(tags[i]);
 			if( tag )
 			{
-				str_array[i] = tag->name;
+				*tptr++ = tag->name;
 			}
-			else
-				str_array[i] = NULL;
 		}
+		*tptr = NULL;
+		
 		tagstring = g_strjoinv(" ", str_array);
 		g_free (str_array);
 	}
@@ -363,6 +388,34 @@ da_tag_debug_list(void)
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
+gboolean
+tag_rename(Tag *item, const gchar *newname)
+{
+Tag *existitem;
+gchar *stripname;
+gboolean retval = FALSE;
+
+	stripname = g_strdup(newname);
+	g_strstrip(stripname);
+
+	existitem = da_tag_get_by_name(stripname);
+
+	if( existitem != NULL && existitem->key != item->key)
+	{
+		DB( g_print("- error, same name already exist with other key %d <> %d\n",existitem->key, item->key) );
+		g_free(stripname);
+	}
+	else
+	{
+		DB( g_print("- renaming\n") );
+		g_free(item->name);
+		item->name = stripname;
+		retval = TRUE;
+	}
+
+	return retval;
+}
+
 
 
 static gint
