@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -21,9 +21,6 @@
 #define __HOMEBANK_IMPORT_H__
 
 
-#define TXN_MAX_ACCOUNT 18
-
-
 #define PAGE_WELCOME		0
 #define PAGE_FILES		1
 #define PAGE_IMPORT		2
@@ -48,8 +45,10 @@ enum
 	NUM_LST_GENTXN
 };
 
+typedef struct _import_txndata ImpTxnData;
 
-struct import_txndata
+
+struct _import_txndata
 {
 	// account page
 	GtkWidget   *IM_txn, *LB_txn;
@@ -93,9 +92,10 @@ struct import_data
 	GtkWidget   *LV_file;
 	GtkWidget   *BT_file_add;
 	GtkWidget   *BT_file_remove;
-	
-	struct import_txndata txndata[TXN_MAX_ACCOUNT];
 
+	//struct import_txndata txndata[TXN_MAX_ACCOUNT];
+	GArray		*txndata;
+	
 	//summary
 	GtkWidget   *TX_summary;
 
