@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2018 Maxime DOYEN
+ *  Copyright (C) 1995-2019 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -250,7 +250,7 @@ GtkTreeViewColumn	*column;
 
 	// treeviewattribute
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(treeview), TRUE);
-	gtk_tree_view_set_reorderable (GTK_TREE_VIEW(treeview), FALSE);
+	gtk_tree_view_set_reorderable (GTK_TREE_VIEW(treeview), TRUE);
 	
 	//gtk_tree_sortable_set_default_sort_func(GTK_TREE_SORTABLE(store), ui_acc_listview_compare_func, NULL, NULL);
 	//gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
@@ -296,6 +296,33 @@ gchar *result = g_new0 (gchar, length+1);
 }
 
 
+static void ui_split_dialog_cb_eval_order(struct ui_split_dialog_data *data)
+{
+GtkTreeModel *model;
+GtkTreeIter	iter;
+gboolean valid;
+guint i;
+
+	DB( g_print("\n[ui_split_dialog] eval order\n") );
+
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_split));
+	i=1; valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
+	while (valid)
+	{
+	Split *split;
+
+		gtk_tree_model_get (model, &iter, 0, &split, -1);
+		split->pos = i;
+
+		DB( g_print("split pos: %d '%s' %.2f\n", i, split->memo, split->amount) );
+		
+		i++; valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
+	}
+
+	da_splits_sort(data->tmp_splits);
+}
+
+
 static void ui_split_dialog_cb_eval_split(GtkWidget *widget, gpointer user_data)
 {
 struct ui_split_dialog_data *data;
@@ -880,6 +907,7 @@ gint row;
 	case GTK_RESPONSE_ACCEPT:
 		if( da_splits_length(data->tmp_splits) )
 		{
+			ui_split_dialog_cb_eval_order(data);
 			// here we swap src_splits <> tmp_splits
 			*src_splits = data->tmp_splits;
 			data->tmp_splits = data->src_splits;
